Authors
==========


Development Lead
----------------

- Maximilian Christ (`maximilianchrist.com <http://maximilianchrist.com>`_)

Contributions
-------------

- Nils Braun  (`nilslennartbraun@gmail.com <nilslennartbraun@gmail.com>`_)
- Julius Neuffer (`julius.neuffer@blue-yonder.com <julius.neuffer@blue-yonder.com>`_)